@@ -1,6 +1,8 @@
 #
 # Copyright (C) 2015 Satoru SATOH <ssato at redhat.com>
+# License: MIT
 #
+# pylint: disable=missing-docstring
 import os
 import unittest
 
@@ -11,7 +13,7 @@ except ImportError:
     TT = None
 
 
-class Test_00(unittest.TestCase):
+class Test00(unittest.TestCase):
 
     def test_10_render(self):
         if TT is not None:
@@ -20,7 +22,7 @@ class Test_00(unittest.TestCase):
             self.assertEquals(egn.renders(tmpl_c), tmpl_c)
 
 
-class Test_10(unittest.TestCase):
+class Test10(unittest.TestCase):
 
     def setUp(self):
         self.workdir = anytemplate.tests.common.setup_workdir()
@@ -40,9 +42,9 @@ class Test_10(unittest.TestCase):
 
         if TT is not None:
             egn = TT.Engine()
-            r = egn.render(tmpl, dict(a="aaa", b="bbb", cs=["c", "d"]),
-                           at_paths=[self.workdir, os.curdir])
-            self.assertEquals(r, exp,
-                              anytemplate.tests.common.diff(r, exp))
+            res = egn.render(tmpl, dict(a="aaa", b="bbb", cs=["c", "d"]),
+                             at_paths=[self.workdir, os.curdir])
+            self.assertEquals(res, exp,
+                              anytemplate.tests.common.diff(res, exp))
 
 # vim:sw=4:ts=4:et:
