@@ -1,5 +1,6 @@
 #
 # Copyright (C) 2015 Satoru SATOH <ssato at redhat.com>
+# License: MIT
 #
 import os.path
 import difflib
@@ -7,10 +8,16 @@ import tempfile
 
 
 def selfdir():
+    """
+    :return: module path itself
+    """
     return os.path.dirname(__file__)
 
 
 def setup_workdir():
+    """
+    :return: Path of the created working dir
+    """
     return tempfile.mkdtemp(dir="/tmp", prefix="python-anytemplate-tests-")
 
 
